@@ -1,6 +1,6 @@
 package Weed::Callbacks;
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 
 use Weed 'X3DCallbacks : X3DArrayHash ()';
 
@@ -33,12 +33,23 @@ sub remove {
 
 	my $objectId   = X3DUniversal::getId( $value->[0] );
 	my $callbackId = X3DUniversal::getId( $value->[1] );
-	
+
 	delete $this->{$objectId}->{$callbackId};
 
 	return;
 }
 
+sub processEvents {
+	my ( $this, $value, $time ) = @_;
+
+	while ( $value->getTainted ) {
+		$value->setTainted(NO);
+		$_->[1]->( $_->[0], $value, $time ) foreach @$this;
+	}
+
+	return;
+}
+
 sub getIndex {
 	my ( $this, $id ) = @_;
 	my $i = 0;
@@ -48,11 +59,5 @@ sub getIndex {
 	return -1;
 }
 
-sub process {
-	my ( $this, $object, $time ) = @_;
-	$object->setTainted(NO);
-	$_->[1]->( $_->[0], $object, $time ) foreach @$this;
-}
-
 1;
 __END__
