@@ -1,6 +1,6 @@
 package X3D::Components::Core::Node;
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 use Weed '
 X3DNode : X3DBaseNode {
@@ -13,14 +13,12 @@ sub new {
 
 	$$this->{self} = new SFNode($this);
 
-	$this->addCallback( $$this->{self}, $this->can("prepareEvents") );
-	$this->addCallback( $$this->{self}, $this->can("processEvent") );
-	$this->addCallback( $$this->{self}, $this->can("eventsProcessed") );
+	$this->getCallbacks->add( $$this->{self}, $this->can("processEvent") );
 
 	$this->can("processEvent")->( $$this->{self}, $this );
 	$this->setTainted(NO);
 
-	$_->addCallback( $$this->{self}, UNIVERSAL::can( $this, $_->getName ) )
+	$_->getCallbacks->add( $$this->{self}, UNIVERSAL::can( $this, $_->getName ) )
 	  foreach grep { $_->getDefinition->isIn } @$this;
 
 	$this->can("initialize")->( $$this->{self}, $this );
@@ -33,7 +31,7 @@ sub initialize { }
 
 sub processEvent {
 	my ( $self, $this, $time ) = @_;
-	$_->processEvents($time) foreach sort { $a->getTainted <=> $b->getTainted } grep { $_->getTainted } @$this;
+	$_->processEvents($time) foreach @$this;
 	return;
 }
 
